==> nui_auth-0.0.44.tar.gz: lib/result/nui_apple_login_result.dart <==
import 'package:nui_core/data/nui_ent.dart';

class NUIAppleLoginResult extends NUIEnt<NUIAppleLoginResult>{
  NUIAppleLoginResult.empty();

  NUIAppleLoginResult({
    this.idToken,
    this.email,
    this.familyName,
    this.givenName,
    this.authCode,
    this.state,
    this.userIdentifier
  });

  String idToken;
  String givenName;
  String email;
  String familyName;
  String authCode;
  String state;
  String userIdentifier;

  @override
  NUIEntMapper<NUIAppleLoginResult> mapper() => NUIAppleLoginResultEnt();
}
class NUIAppleLoginResultEnt extends NUIEntMapper<NUIAppleLoginResult>{
  @override
  String entityName() => "NUIAppleLoginResult";

  @override
  List<NUIEntField> fields() => [
    NUIEntField<NUIAppleLoginResult>(name: "idToken", type: NUIEntType.STRING, setter: (data, value) => data.idToken = value, getter: (data) => data.idToken),
    NUIEntField<NUIAppleLoginResult>(name: "email", type: NUIEntType.STRING, setter: (data, value) => data.email = value, getter: (data) => data.email),
    NUIEntField<NUIAppleLoginResult>(name: "familyName", type: NUIEntType.STRING, setter: (data, value) => data.familyName = value, getter: (data) => data.familyName),
    NUIEntField<NUIAppleLoginResult>(name: "givenName", type: NUIEntType.STRING, setter: (data, value) => data.givenName = value, getter: (data) => data.givenName),
    NUIEntField<NUIAppleLoginResult>(name: "authCode", type: NUIEntType.STRING, setter: (data, value) => data.authCode = value, getter: (data) => data.authCode),
    NUIEntField<NUIAppleLoginResult>(name: "state", type: NUIEntType.STRING, setter: (data, value) => data.state = value, getter: (data) => data.state),
    NUIEntField<NUIAppleLoginResult>(name: "userIdentifier", type: NUIEntType.STRING, setter: (data, value) => data.userIdentifier = value, getter: (data) => data.userIdentifier),
  ];

  @override
  NUIAppleLoginResult newInstance() => NUIAppleLoginResult.empty();
}

==> nui_auth-1.0.3.tar.gz: lib/result/nui_apple_login_result.dart <==
import 'package:nui_core/data/nui_ent.dart';

class NUIAppleLoginResult extends NUIEnt<NUIAppleLoginResult>{
  NUIAppleLoginResult.empty();

  NUIAppleLoginResult({
    this.idToken,
    this.email,
    this.familyName,
    this.givenName,
    required this.authCode,
    this.state,
    this.userIdentifier
  });

  String? idToken;
  String? givenName;
  String? email;
  String? familyName;
  late String authCode;
  String? state;
  String? userIdentifier;

  @override
  NUIEntMapper<NUIAppleLoginResult> mapper() => NUIAppleLoginResultEnt();
}
class NUIAppleLoginResultEnt extends NUIEntMapper<NUIAppleLoginResult>{
  @override
  String entityName() => "NUIAppleLoginResult";

  @override
  List<NUIEntField> fields() => [
    NUIEntField<NUIAppleLoginResult>(name: "idToken", type: NUIEntType.STRING, setter: (data, value) => data.idToken = value, getter: (data) => data.idToken),
    NUIEntField<NUIAppleLoginResult>(name: "email", type: NUIEntType.STRING, setter: (data, value) => data.email = value, getter: (data) => data.email),
    NUIEntField<NUIAppleLoginResult>(name: "familyName", type: NUIEntType.STRING, setter: (data, value) => data.familyName = value, getter: (data) => data.familyName),
    NUIEntField<NUIAppleLoginResult>(name: "givenName", type: NUIEntType.STRING, setter: (data, value) => data.givenName = value, getter: (data) => data.givenName),
    NUIEntField<NUIAppleLoginResult>(name: "authCode", type: NUIEntType.STRING, setter: (data, value) => data.authCode = value, getter: (data) => data.authCode),
    NUIEntField<NUIAppleLoginResult>(name: "state", type: NUIEntType.STRING, setter: (data, value) => data.state = value, getter: (data) => data.state),
    NUIEntField<NUIAppleLoginResult>(name: "userIdentifier", type: NUIEntType.STRING, setter: (data, value) => data.userIdentifier = value, getter: (data) => data.userIdentifier),
  ];

  @override
  NUIAppleLoginResult newInstance() => NUIAppleLoginResult.empty();
}
